@@ -12,6 +12,7 @@ from agentbox.exceptions import format_request_timeout_error
 from agentbox.sandbox.main import SandboxSetup
 from agentbox.sandbox.utils import class_method_variant
 from agentbox.sandbox_async.adb_shell.adb_shell import ADBShell
+from agentbox.sandbox_async.adb_shell2.adb_shell2 import ADBShell2
 from agentbox.sandbox_async.filesystem.filesystem import AgentBoxFilesystem as Filesystem
 from agentbox.sandbox_async.commands.command import Commands
 from agentbox.sandbox_async.commands.pty import Pty
@@ -112,6 +113,13 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
         Module for adb shell in the sandbox.
         """
         return self._adb_shell
+    
+    @property
+    def adb_shell2(self) -> ADBShell2:
+        """
+        Module for adb shell2 in the sandbox.
+        """
+        return self._adb_shell2
 
     @property
     def _envd_access_token(self) -> str:
@@ -193,6 +201,10 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
                 adb_auth_command = self._adb_auth_command,
                 adb_auth_password = self._adb_auth_password
             )
+            self._adb_shell2 = ADBShell2(
+                connection_config=self.connection_config,
+                sandbox_id=self._sandbox_id
+            )
         else:
             self._transport = AsyncTransportWithLogger(
                 limits=self._limits, proxy=self._connection_config.proxy
@@ -280,7 +292,7 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
         :param timeout: Timeout for the sandbox in **seconds**, default to 300 seconds. Maximum time a sandbox can be kept alive is 24 hours (86_400 seconds) for Pro users and 1 hour (3_600 seconds) for Hobby users.
         :param metadata: Custom metadata for the sandbox
         :param envs: Custom environment variables for the sandbox
-        :param api_key: E2B API Key to use for authentication, defaults to `E2B_API_KEY` environment variable
+        :param api_key: E2B API Key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
         :param request_timeout: Timeout for the request in **seconds**
         :param proxy: Proxy to use for the request and for the **requests made to the returned sandbox**
         :param secure: Envd is secured with access token and cannot be used without it
@@ -397,7 +409,7 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
         With sandbox ID you can connect to the same sandbox from different places or environments (serverless functions, etc).
 
         :param sandbox_id: Sandbox ID
-        :param api_key: E2B API Key to use for authentication, defaults to `E2B_API_KEY` environment variable
+        :param api_key: E2B API Key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
         :param proxy: Proxy to use for the request and for the **requests made to the returned sandbox**
 
         :return: sandbox instance for the existing sandbox
@@ -502,7 +514,7 @@ class AsyncSandbox(SandboxSetup, SandboxApi):
         Kill the sandbox specified by sandbox ID.
 
         :param sandbox_id: Sandbox ID
-        :param api_key: E2B API Key to use for authentication, defaults to `E2B_API_KEY` environment variable
+        :param api_key: E2B API Key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
         :param request_timeout: Timeout for the request in **seconds**
         :param proxy: Proxy to use for the request
 
